@@ -115,6 +115,7 @@ class SVMONReport:
                         exit(1)
             else:
                 self.tags = services.get_service_tag(self.service_type)
+                self.service_names = services.get_service_name(self.service_type)
 
     def get_site(self):
         return self.site
@@ -160,6 +161,9 @@ class SVMONReport:
         this.tags.append(tag)
 
     def print_report(self):
+        enableDebug = self.config["DEBUG_MODE"]
+        if(enableDebug):
+            print('print_report called with services: ', self.service_names)
         if len(self.service_names) > 0:
             res=[]
             if self.service_names== None or len(self.service_names ) < 1:
